==> newsx-1.3.tar.gz: newsx-1.3/src/options.h <==
/*  VER 142  TAB P   $Id: options.h,v 1.16 1998/11/22 08:23:07 src Exp $
 *
 *  command line options
 *
 *  copyright 1996, 1997, 1998 Egil Kvaleberg, egil@kvaleberg.no
 *  the GNU General Public License applies
 *
 *  $Log: options.h,v $
 *  Revision 1.16  1998/11/22 08:23:07  src
 *  Added --forget-inactive
 *
 *  Revision 1.15  1998/11/22 08:00:08  src
 *  Option --no-queue
 *
 *  Revision 1.14  1998/11/21 19:14:24  src
 *  Added --filter option
 *
 *  Revision 1.13  1998/09/21 10:04:29  src
 *  Added new command line options for --inews
 *
 *  Revision 1.12  1998/09/18 07:30:59  src
 *  Implemented --inews
 *
 *  Revision 1.11  1998/09/11 09:17:43  src
 *  Check path consistency (--no-path) and length (--max-path)
 *  GNU style option --help, --version, --dry-run, changed --noxx to --no-xx
 *  Check for putenv and setenv, added xstrcpy
 *
 *  Revision 1.10  1998/09/09 07:32:13  src
 *  Version 1.1
 *
 *  Revision 1.9  1998/09/02 06:50:31  src
 *  newsx version 1.0
 *
 *  Revision 1.8  1998/09/02 06:34:41  src
 *  Support @-syntax in newsfeeds, and support AUTHINFO GENERIC
 *
 *  Revision 1.7  1998/08/24 06:17:15  src
 */

char *ai_username,*ai_password; /* -a username/password */
int minspool;                   /* -b n */
int debug_opt;                  /* -d */
char *end_tag;                  /* -e end_tag */
char *folder;                   /* -f folder */
int nopull_opt;                 /* -g */
char *history;                  /* -h history */
int inn_opt;                    /* -i */
int keep_path_opt;              /* -k */
char *logfile;                  /* -l logfile */
int nomsgid_opt;                /* -m */
int noaction_opt;               /* -n */
int keep_old_opt;               /* -o */
int nopost_opt;                 /* -p */
char *enquire_opt;              /* -q msgid */
int mode_reader_opt;            /* -r */
long timeout;                   /* -t n */
int noforce_opt;                /* -u */
char *chat_file;                /* -w chat */
char *connect_exec;             /* -x cmd */
char *via_exec;                 /* -y cmd */
int zap_opt;                    /* -z */
char *active;                   /* -A active */
char *batch;                    /* -B batch */
char *ctlpgm;                   /* -C ctlinnd */
int conterr;                    /* -E ignore */
long failtime;                  /* -F when to kill failed msgs */
char *group_newlist;            /* -G newlist */
char *newshome;                 /* -H newshome */
char *incoming;                 /* -I incoming */
int ihave_opt;                  /* -J */
char *inhosts;                  /* -K in.hosts */
char *group_list;               /* -L list */
char *newsfeeds;                /* -N newsfeeds */
char *bounce;                   /* -O bounce */
char *locks;                    /* -P locks */
char *statfile;                 /* -Q statfile */
int reset_opt;                  /* -R reset */
char *togo;                     /* -T togo */
int rnews_opt;                  /* --rnews */
int window;                     /* -W windowsize */
extern char *newline;           /* -X newline */
int zapnew_opt;                 /* -Z */
char *add_header;               /* --add-header */
char *group_alldesc;            /* --alldesc */
int attach;                     /* --attach */
int ai_isgeneric;               /* --authgeneric */
int forget_inactive;            /* --forget-inactive */
char *group_desc;               /* --desc */
char *filter;                   /* --filter prog */
int inews_opt;                  /* --inews */
char *inews_options;            /* --inews-options */
int max_path;                   /* --maxpath */
int no_host_lock;               /* --nohostlock */
int no_next;                    /* --nonext */
int nopath_opt;                 /* --nopath */
int no_ps;                      /* --no_ps */
int stat_attempts;              /* --missing num */
int max_articles;               /* --maxart num */
int max_new;                    /* --maxnew num */
char *mfilter;                  /* --mfilter prog */
int noqueue;                    /* --no-queue */
int readbeforeauth_opt;         /* --readbeforeauth */

==> newsx_1.4.orig.tar.gz: newsx-1.4/src/options.h <==
/*  VER 155  TAB P   $Id: options.h,v 1.22 1999/04/07 20:09:16 src Exp $
 *
 *  command line options
 *  see also newsconfig.h for a range of options
 *
 *  copyright 1996, 1997, 1998 Egil Kvaleberg, egil@kvaleberg.no
 *  the GNU General Public License applies
 *
 *  $Log: options.h,v $
 *  Revision 1.22  1999/04/07 20:09:16  src
 *  Implemented configuration reading, and eval mechanism
 *
 *  Revision 1.21  1999/04/07 07:10:56  src
 *  Implemented --tag
 *
 *  Revision 1.20  1999/04/05 19:01:51  src
 *  Lock for scanlogs
 *
 *  Revision 1.19  1999/03/16 17:35:38  src
 *  Version 1.4pre
 *
 *  Revision 1.18  1999/03/11 07:30:01  src
 *  Implemented check for spool free space
 *
 *  Revision 1.17  1999/03/07 14:58:18  src
 *  Read newsconfig supported. Storage API supported.
 *
 *  Revision 1.16  1998/11/22 08:23:07  src
 *  Added --forget-inactive
 *
 *  Revision 1.15  1998/11/22 08:00:08  src
 *  Option --no-queue
 *
 *  Revision 1.14  1998/11/21 19:14:24  src
 *  Added --filter option
 *
 *  Revision 1.13  1998/09/21 10:04:29  src
 *  Added new command line options for --inews
 *
 *  Revision 1.12  1998/09/18 07:30:59  src
 *  Implemented --inews
 *
 *  Revision 1.11  1998/09/11 09:17:43  src
 *  Check path consistency (--no-path) and length (--max-path)
 *  GNU style option --help, --version, --dry-run, changed --noxx to --no-xx
 *  Check for putenv and setenv, added xstrcpy
 *
 *  Revision 1.10  1998/09/09 07:32:13  src
 *  Version 1.1
 *
 *  Revision 1.9  1998/09/02 06:50:31  src
 *  newsx version 1.0
 *
 *  Revision 1.8  1998/09/02 06:34:41  src
 *  Support @-syntax in newsfeeds, and support AUTHINFO GENERIC
 *
 *  Revision 1.7  1998/08/24 06:17:15  src
 */

char *ai_username,*ai_password; /* -a username/password */
long minspool;                  /* -b n */
int debug_opt;                  /* -d */
char *end_tag;                  /* -e end_tag */
char *folder;                   /* -f folder */
int nopull_opt;                 /* -g */
int inn_opt;                    /* -i */
int keep_path_opt;              /* -k */
char *logfile;                  /* -l logfile */
int nomsgid_opt;                /* -m */
int noaction_opt;               /* -n */
int keep_old_opt;               /* -o */
int nopost_opt;                 /* -p */
char *enquire_opt;              /* -q msgid */
int mode_reader_opt;            /* -r */
long timeout;                   /* -t n */
int noforce_opt;                /* -u */
char *chat_file;                /* -w chat */
char *connect_exec;             /* -x cmd */
char *via_exec;                 /* -y cmd */
int zap_opt;                    /* -z */
char *ctlpgm;                   /* -C ctlinnd */
int conterr;                    /* -E ignore */
long failtime;                  /* -F when to kill failed msgs */
char *group_newlist;            /* -G newlist */
int ihave_opt;                  /* -J */
char *group_list;               /* -L list */
char *bounce;                   /* -O bounce */
char *statfile;                 /* -Q statfile */
int reset_opt;                  /* -R reset */
char *togo;                     /* -T togo */
int rnews_opt;                  /* --rnews */
int window;                     /* -W windowsize */
extern char *newline;           /* -X newline */
int zapnew_opt;                 /* -Z */
char *add_header;               /* --add-header */
char *group_alldesc;            /* --alldesc */
int attach;                     /* --attach */
int ai_isgeneric;               /* --authgeneric */
int forget_inactive;            /* --forget-inactive */
char *group_desc;               /* --desc */
char *filter;                   /* --filter prog */
int inews_opt;                  /* --inews */
char *inews_options;            /* --inews-options */
int max_path;                   /* --maxpath */
int no_host_lock;               /* --nohostlock */
int no_next;                    /* --nonext */
int nopath_opt;                 /* --nopath */
int no_ps;                      /* --no-ps */
int stat_attempts;              /* --missing num */
int max_articles;               /* --maxart num */
int max_new;                    /* --maxnew num */
char *mfilter;                  /* --mfilter prog */
int noqueue;                    /* --no-queue */
int readbeforeauth_opt;         /* --readbeforeauth */
long minfree;                   /* --minfree n */
int keep_fake;                  /* --keep-fake */
int scanlogs_lock;              /* --scanlogs */
int tag_opt;                    /* --tag */
int verify_opt;                 /* --verify */
